@@ -2,7 +2,7 @@
 
 #  FLAC - Free Lossless Audio Codec
 #  Copyright (C) 2001-2009  Josh Coalson
-#  Copyright (C) 2011-2014  Xiph.Org Foundation
+#  Copyright (C) 2011-2016  Xiph.Org Foundation
 #
 #  This file is part the FLAC project.  FLAC is comprised of several
 #  components distributed under different licenses.  The codec libraries
@@ -47,12 +47,6 @@ run_test_picture ()
 	fi
 }
 
-if [ `env | grep -ic '^comspec='` != 0 ] ; then
-	is_win=yes
-else
-	is_win=no
-fi
-
 ########################################################################
 #
 # test_picture
@@ -60,7 +54,7 @@ fi
 ########################################################################
 
 log=picture.log
-picture_dir=pictures
+picture_dir=${top_srcdir}/test/pictures
 
 echo "Running test_picture..."
 
@@ -69,9 +63,9 @@ rm -f $log
 run_test_picture $picture_dir >> $log 2>&1
 
 if [ $is_win = yes ] ; then
-	diff -w picture.ok $log > picture.diff || die "Error: .log file does not match .ok file, see picture.diff"
+	diff -w ${top_srcdir}/test/picture.ok $log > picture.diff || die "Error: .log file does not match .ok file, see picture.diff"
 else
-	diff picture.ok $log > picture.diff || die "Error: .log file does not match .ok file, see picture.diff"
+	diff ${top_srcdir}/test/picture.ok $log > picture.diff || die "Error: .log file does not match .ok file, see picture.diff"
 fi
 
 echo "PASSED (results are in $log)"
@@ -83,8 +77,8 @@ echo "PASSED (results are in $log)"
 ########################################################################
 
 log=cuesheet.log
-bad_cuesheets=cuesheets/bad.*.cue
-good_cuesheets=cuesheets/good.*.cue
+bad_cuesheets=${top_srcdir}/test/cuesheets/bad.*.cue
+good_cuesheets=${top_srcdir}/test/cuesheets/good.*.cue
 good_leadout=`expr 80 \* 60 \* 44100`
 bad_leadout=`expr $good_leadout + 1`
 
@@ -96,7 +90,7 @@ rm -f $log
 # negative tests
 #
 for cuesheet in $bad_cuesheets ; do
-	echo "NEGATIVE $cuesheet" >> $log 2>&1
+	echo "NEGATIVE $cuesheet" | sed "s|${top_srcdir}/test/||" >> $log 2>&1
 	run_test_cuesheet $cuesheet $good_leadout 44100 cdda >> $log 2>&1 || exit_code=$?
 	if [ "$exit_code" = 255 ] ; then
 		die "Error: test script is broken"
@@ -110,7 +104,7 @@ done
 # positve tests
 #
 for cuesheet in $good_cuesheets ; do
-	echo "POSITIVE $cuesheet" >> $log 2>&1
+	echo "POSITIVE $cuesheet" | sed "s|${top_srcdir}/test/||" >> $log 2>&1
 	run_test_cuesheet $cuesheet $good_leadout 44100 cdda >> $log 2>&1
 	exit_code=$?
 	if [ "$exit_code" = 255 ] ; then
@@ -118,16 +112,17 @@ for cuesheet in $good_cuesheets ; do
 	elif [ "$exit_code" != 0 ] ; then
 		die "Error: good cuesheet is broken"
 	fi
-	cuesheet_pass1=${cuesheet}.1
-	cuesheet_pass2=${cuesheet}.2
+	cuesheet_out=$(echo $cuesheet | sed "s|${top_srcdir}/test/||")
+	cuesheet_pass1=${cuesheet_out}.1
+	cuesheet_pass2=${cuesheet_out}.2
 	diff $cuesheet_pass1 $cuesheet_pass2 >> $log 2>&1 || die "Error: pass1 and pass2 output differ"
 	rm -f $cuesheet_pass1 $cuesheet_pass2
 done
 
 if [ $is_win = yes ] ; then
-	diff -w cuesheet.ok $log > cuesheet.diff || die "Error: .log file does not match .ok file, see cuesheet.diff"
+	diff -w ${top_srcdir}/test/cuesheet.ok $log > cuesheet.diff || die "Error: .log file does not match .ok file, see cuesheet.diff"
 else
-	diff cuesheet.ok $log > cuesheet.diff || die "Error: .log file does not match .ok file, see cuesheet.diff"
+	diff ${top_srcdir}/test/cuesheet.ok $log > cuesheet.diff || die "Error: .log file does not match .ok file, see cuesheet.diff"
 fi
 
 echo "PASSED (results are in $log)"
